@@ -7,6 +7,7 @@ package Gtk::Types;
 @Gtk::Box::ISA = 'Gtk::Container';
 @Gtk::Button::ISA = 'Gtk::Container';
 @Gtk::ButtonBox::ISA = 'Gtk::Box';
+@Gtk::CList::ISA = 'Gtk::Container';
 @Gtk::CheckButton::ISA = 'Gtk::ToggleButton';
 @Gtk::CheckMenuItem::ISA = 'Gtk::MenuItem';
 @Gtk::ColorSelection::ISA = 'Gtk::VBox';
@@ -17,7 +18,8 @@ package Gtk::Types;
 @Gtk::Data::ISA = 'Gtk::Object';
 @Gtk::Dialog::ISA = 'Gtk::Window';
 @Gtk::DrawingArea::ISA = 'Gtk::Widget';
-@Gtk::Entry::ISA = 'Gtk::Widget';
+@Gtk::Editable::ISA = 'Gtk::Widget';
+@Gtk::Entry::ISA = 'Gtk::Editable';
 @Gtk::EventBox::ISA = 'Gtk::Bin';
 @Gtk::FileSelection::ISA = 'Gtk::Window';
 @Gtk::Fixed::ISA = 'Gtk::Container';
@@ -30,9 +32,9 @@ package Gtk::Types;
 @Gtk::HScale::ISA = 'Gtk::Scale';
 @Gtk::HScrollbar::ISA = 'Gtk::Scrollbar';
 @Gtk::HSeparator::ISA = 'Gtk::Separator';
-@Gtk::HandleBox::ISA = 'Gtk::EventBox';
+@Gtk::HandleBox::ISA = 'Gtk::Bin';
 @Gtk::Image::ISA = 'Gtk::Misc';
-@Gtk::InputDialog::ISA = 'Gtk::Window';
+@Gtk::InputDialog::ISA = 'Gtk::Dialog';
 @Gtk::Item::ISA = 'Gtk::Bin';
 @Gtk::Label::ISA = 'Gtk::Misc';
 @Gtk::List::ISA = 'Gtk::Container';
@@ -56,10 +58,14 @@ package Gtk::Types;
 @Gtk::Scrollbar::ISA = 'Gtk::Range';
 @Gtk::ScrolledWindow::ISA = 'Gtk::Container';
 @Gtk::Separator::ISA = 'Gtk::Widget';
+@Gtk::SpinButton::ISA = 'Gtk::Entry';
+@Gtk::Statusbar::ISA = 'Gtk::HBox';
 @Gtk::Table::ISA = 'Gtk::Container';
-@Gtk::Text::ISA = 'Gtk::Widget';
+@Gtk::Text::ISA = 'Gtk::Editable';
+@Gtk::TipsQuery::ISA = 'Gtk::Label';
 @Gtk::ToggleButton::ISA = 'Gtk::Button';
 @Gtk::Toolbar::ISA = 'Gtk::Container';
+@Gtk::Tooltips::ISA = 'Gtk::Data';
 @Gtk::Tree::ISA = 'Gtk::Container';
 @Gtk::TreeItem::ISA = 'Gtk::Item';
 @Gtk::VBox::ISA = 'Gtk::Box';
